@@ -1,6 +1,7 @@
 import typer
-from .utils import start_app, start_project, select_database
-
+from .project_utils import start_app, start_project, select_database, run_server
+from .models_utils import show_models
+import pkg_resources
 
 app = typer.Typer(
     add_completion=False,
@@ -20,8 +21,14 @@ def startapp(appname: str = typer.Argument(...)):
     start_app(appname)
 
 
-# TODO
-# @app.command(help="Runs server")
-# def runserver(server: str = typer.Argument("uvicorn")):
-#     run_server()
+@app.command(help="Runs the development server")
+def runserver():
+    installed_pkgs = [d.project_name for d in pkg_resources.working_set]
+    if "uvicorn" not in installed_pkgs:
+        print(f"Default(uvicorn) server not found in installed packages.")
+    run_server()
 
+
+@app.command(help="Shows all Pydantic models")
+def showmodels():
+    show_models()
